import { Component, OnInit, ViewChild } from '@angular/core';
import { MatButton } from '@angular/material/button';
import { ActivatedRoute, Router } from '@angular/router';
import { ParkingService, PremiseService } from '../data-object-service';
import { NULL_Parking, NULL_Premise, Parking, Premise } from '../data-objects';
import { MessageService } from '../message.service';

@Component({
  selector: 'app-parking-details',
  templateUrl: './parking-details.component.html',
  styleUrls: ['./parking-details.component.css']
})
export class ParkingDetailsComponent implements OnInit {

  @ViewChild('submitButton') submitButton: MatButton
  
  parking: Parking = NULL_Parking
  premise: Premise = NULL_Premise

  premises: Premise[]

  constructor(
    private parkingService: ParkingService,
    private premiseService: PremiseService,
    private messageService: MessageService,
    private route: ActivatedRoute,
    private router: Router
  ) { }



  async getParking(): Promise<void> {
    try {
      const id = +this.route.snapshot.paramMap.get('id')
      if (id != 0) {
        this.parking = await this.parkingService.getParking(id)
        this.premise = await this.premiseService.getPremise(this.parking.premise)
      }
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  async getPremises(): Promise<void> {
    try {
      this.messageService.add("Trying to load premises")
      this.premises = await this.premiseService.getPremises()
      this.messageService.add("Premises loaded")
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }
  
  async saveParking() {
    try {
      this.submitButton.disabled = true
      this.messageService.add(`saveParking: ${ JSON.stringify(this.parking, undefined, 4) }`)
      if (this.parking.id == 0) {
        this.messageService.add("about to insert new parking")
        this.parking = await this.parkingService.postParking(this.parking)
        this.messageService.add(`Successfully added parking with id ${this.parking.id}`)
      } else {
        this.messageService.add("about to update existing parking")
        this.parking = await this.parkingService.putParking(this.parking)
        this.messageService.add(`Successfully changed parking with id ${this.parking.id}`)
      }
      this.router.navigate(['/parkings'])
    } finally {
      this.submitButton.disabled = false
    }
  }


  ngOnInit(): void {
    this.getPremises()
    this.getParking()
  }

}
